@@ -34,6 +34,22 @@ TmpXError(Display * d, XErrorEvent * ev)
    ev = NULL;
 }
 
+/* "safe" realloc allowing handling of out-of-memory situations */
+static void        *
+_safe_realloc(void *ptr, size_t size, int *err)
+{
+   void               *ptr_new;
+
+   ptr_new = realloc(ptr, size);
+   if (!ptr_new)
+     {
+        *err = 1;
+        return ptr;
+     }
+
+   return ptr_new;
+}
+
 void
 __imlib_SetMaxXImageCount(Display * d, int num)
 {
@@ -116,10 +132,10 @@ __imlib_FlushXImage(Display * d)
                   else
                     {
                        list_xim =
-                           realloc(list_xim, sizeof(XImage *) * list_num);
+                          realloc(list_xim, sizeof(XImage *) * list_num);
                        list_si =
-                           realloc(list_si,
-                                   sizeof(XShmSegmentInfo *) * list_num);
+                          realloc(list_si,
+                                  sizeof(XShmSegmentInfo *) * list_num);
                        list_used = realloc(list_used, sizeof(char) * list_num);
                        list_d = realloc(list_d, sizeof(Display *) * list_num);
                     }
@@ -158,7 +174,7 @@ __imlib_ProduceXImage(Display * d, Visual * v, int depth, int w, int h,
                       char *shared)
 {
    XImage             *xim;
-   int                 i;
+   int                 i, err;
 
    /* if we havent check the shm extension before - see if its there */
    if (x_does_shm < 0)
@@ -176,17 +192,16 @@ __imlib_ProduceXImage(Display * d, Visual * v, int depth, int w, int h,
    /* go thru the current image list */
    for (i = 0; i < list_num; i++)
      {
-	  int depth_ok = 0;
+        int                 depth_ok = 0;
 
         /* if the image has the same depth, width and height - recycle it */
         /* as long as its not used */
         if (list_xim[i]->depth == depth)
-            depth_ok = 1;
-	  if ( depth_ok &&
-	     (list_xim[i]->width >= w) &&
-	     (list_xim[i]->height >= h) &&
-	     /*	  (list_d[i] == d) && */
-	     (!list_used[i]))
+           depth_ok = 1;
+        if (depth_ok &&
+            (list_xim[i]->width >= w) && (list_xim[i]->height >= h) &&
+            /*   (list_d[i] == d) && */
+            (!list_used[i]))
           {
              /* mark it as used */
              list_used[i] = 1;
@@ -197,24 +212,28 @@ __imlib_ProduceXImage(Display * d, Visual * v, int depth, int w, int h,
              return list_xim[i];
           }
      }
+
    /* can't find a usable XImage on the cache - create one */
    /* add the new XImage to the XImage cache */
    list_num++;
-   if (list_num == 1)
+   err = 0;
+   list_xim = _safe_realloc(list_xim, sizeof(XImage *) * list_num, &err);
+   list_si = _safe_realloc(list_si, sizeof(XShmSegmentInfo *) * list_num, &err);
+   list_used = _safe_realloc(list_used, sizeof(char) * list_num, &err);
+   list_d = _safe_realloc(list_d, sizeof(Display *) * list_num, &err);
+   if (err)
      {
-        list_xim = malloc(sizeof(XImage *) * list_num);
-        list_si = malloc(sizeof(XShmSegmentInfo *) * list_num);
-        list_used = malloc(sizeof(char) * list_num);
-        list_d = malloc(sizeof(Display *) * list_num);
-     }
-   else
-     {
-        list_xim = realloc(list_xim, sizeof(XImage *) * list_num);
-        list_si = realloc(list_si, sizeof(XShmSegmentInfo *) * list_num);
-        list_used = realloc(list_used, sizeof(char) * list_num);
-        list_d = realloc(list_d, sizeof(Display *) * list_num);
+        /* failed to allocate memory */
+        list_num--;
+        return NULL;
      }
    list_si[list_num - 1] = malloc(sizeof(XShmSegmentInfo));
+   if (!list_si[list_num - 1])
+     {
+        /* failed to allocate memory */
+        list_num--;
+        return NULL;
+     }
 
    /* work on making a shared image */
    xim = NULL;
@@ -231,15 +250,15 @@ __imlib_ProduceXImage(Display * d, Visual * v, int depth, int w, int h,
              list_xim[list_num - 1] = xim;
              /* get an shm id of this image */
              list_si[list_num - 1]->shmid =
-                 shmget(IPC_PRIVATE, xim->bytes_per_line * xim->height,
-                        IPC_CREAT | 0777);
+                shmget(IPC_PRIVATE, xim->bytes_per_line * xim->height,
+                       IPC_CREAT | 0777);
              /* if the get succeeds */
              if (list_si[list_num - 1]->shmid != -1)
                {
                   /* set the params for the shm segment */
                   list_si[list_num - 1]->readOnly = False;
                   list_si[list_num - 1]->shmaddr = xim->data =
-                      shmat(list_si[list_num - 1]->shmid, 0, 0);
+                     shmat(list_si[list_num - 1]->shmid, 0, 0);
                   /* get the shm addr for this data chunk */
                   if (xim->data != (char *)-1)
                     {
@@ -310,7 +329,16 @@ __imlib_ProduceXImage(Display * d, Visual * v, int depth, int w, int h,
         /* create a normal ximage */
         xim = XCreateImage(d, v, depth, ZPixmap, 0, NULL, w, h, 32, 0);
         /* allocate data for it */
-        xim->data = malloc(xim->bytes_per_line * xim->height);
+        if (xim)
+           xim->data = malloc(xim->bytes_per_line * xim->height);
+        if (!xim || !xim->data)
+          {
+             /* failed to create XImage or allocate data memory */
+             if (xim)
+                XDestroyImage(xim);
+             list_num--;
+             return NULL;
+          }
         /* add xim to our list */
         list_xim[list_num - 1] = xim;
         /* incriment our memory count */
