@@ -52,6 +52,8 @@ xpm_parse_color(char *color, int *r, int *g, int *b)
    /* look in rgb txt database */
    if (!rgb_txt)
 #ifndef __EMX__
+     rgb_txt = fopen("/usr/share/X11/rgb.txt", "r");
+   if (!rgb_txt)
      rgb_txt = fopen("/usr/X11R6/lib/X11/rgb.txt", "r");
    if (!rgb_txt)
      rgb_txt = fopen("/usr/openwin/lib/X11/rgb.txt", "r");
@@ -97,7 +99,7 @@ load(ImlibImage * im, ImlibProgressFunction progress, char progress_granularity,
 
    int                 pc, c, i, j, k, w, h, ncolors, cpp, comment, transp,
        quote, context, len, done, r, g, b, backslash;
-   char               *line, s[256], tok[128], col[256];
+   char               *line, s[256], tok[256], col[256];
    int                 lsz = 256;
    struct _cmap {
       unsigned char       str[6];
@@ -151,6 +153,9 @@ load(ImlibImage * im, ImlibProgressFunction progress, char progress_granularity,
    pixels = 0;
    count = 0;
    line = malloc(lsz);
+   if (!line)
+     return 0;
+
    backslash = 0;
    memset(lookup, 0, sizeof(lookup));
    while (!done)
@@ -286,7 +291,7 @@ load(ImlibImage * im, ImlibProgressFunction progress, char progress_granularity,
                                  if (line[k] != ' ')
                                    {
                                       s[0] = 0;
-                                      sscanf(&line[k], "%65535s", s);
+                                      sscanf(&line[k], "%255s", s);
                                       slen = strlen(s);
                                       k += slen;
                                       if (!strcmp(s, "c"))
